//
// HtHTTPBasic.cc
//
// HtHTTPBasic: Class for HTTP messaging (derived from Transport)
//              Does not handle HTTPS connections -- use HtHTTPSecure
//
// Part of the ht://Dig package   <http://www.htdig.org/>
// Copyright (c) 1995-2003 The ht://Dig Group
// For copyright details, see the file COPYING in your distribution
// or the GNU Public License version 2 or later
// <http://www.gnu.org/copyleft/gpl.html>
//
// $Id: HtHTTPBasic.cc,v 1.3 2003/06/20 16:47:30 mnencia Exp $ 
//

#ifdef HAVE_CONFIG_H
#include "htconfig.h"
#endif /* HAVE_CONFIG_H */

#ifdef HAVE_STD
#include <iostream>
#ifdef HAVE_NAMESPACES
using namespace std;
#endif
#else
#include <iostream.h>
#endif /* HAVE_STD */

#include "HtHTTPBasic.h"

// HtHTTPBasic constructor
//
HtHTTPBasic::HtHTTPBasic()
: HtHTTP(*(new Connection()))
{
}

// HtHTTPBasic destructor
//
HtHTTPBasic::~HtHTTPBasic()
{
}

